Learn R Programming

pestr (version 0.8.4)

eppo_citation: Citation helper tools

Description

[Experimental] Citation returns citation of EPPO Data Services and/or EPPO Global Database in bibtex format. To save the output into file use output argument with destination file name.

Usage

eppo_citation(cite, output = NULL)

Value

citation of EPPO Data Services, EPPO Global Database or both in bibtex format.

Arguments

cite

string. Possible values: 'data_services', 'global_database' or 'both'.

output

string. Name of the file to which output will be saved. If NULL (default) results will be printed to console.

Examples

Run this code
eppo_citation("data_services")
eppo_citation("global_database")
eppo_citation("both")

Run the code above in your browser using DataLab