Learn R Programming

pestr (version 0.8.4)

eppo_names_tables: EPPO Data Services SQLite Database search tools

Description

[Maturing] eppo_names_table checks if string (names or parts of the names) provided by user match any name in the EPPO database. If strings match any name in database, data frame with all names matching codeid, as well as preferred (binary), language and EPPOcode is returned.

Value

Check if provided names are present in EPPO SQLite Database. Creates list which contains: data frame with matching names in database and their codeids, character vector of names from names_vector which do not match any entry in database, data frame with preferred names and their codeids, and data frame containing all names matching codeids of preferred names. Last data frame contains also column with preferred (binary), codelang (two letter character with language code), and EPPOcode.

Arguments

names_vector

A vector with organism or viruses names (or part of the names) to be checked for existence in EPPO SQLite Database.

sqlConnection

connection to SQLite EPPO Database. By default NULL; function will automatically connect to database with default credentials.

Using with other functions

Output of the function might be passed to functions:

  • eppo_tabletools_names

  • eppo_tabletools_cat

  • eppo_tabletools_hosts

  • eppo_tabletools_distribution

Examples

Run this code
if (FALSE) {
  ##This code needs SQLite dabatase in working directory
  test_names <- c("Xylella", "dog", "leafhopper")
  test_names_table <- eppo_names_table(test_names)
}

Run the code above in your browser using DataLab