eppo_table_full creates table in human friendly format with data on
pest preferred name, synonyms and common names, hosts, categorization,
taxonomy and its distribution.
eppo_table_full(names_vector, sqlConnection, token)Wraps results of function from eppo_tabletools, namely:
eppo_tabletools_names, eppo_tabletools_hosts,
eppo_tabletools_cat, eppo_tabletools_taxo, and
eppo_tabletools_distri into one compact, human readable table.
A vector with organism names (or part of the names) to be checked for existence in EPPO SQLite Database.
connection to SQLite EPPO Database. By default NULL; function will automatically connect to database with default credentials.
An object containing EPPO API token created via create_eppo_token.