Citation returns citation of EPPO Data Services and/or EPPO Global Database
in bibtex format. To save the output into file use output argument
with destination file name.
Usage
eppo_citation(cite, output = NULL)
Value
citation of EPPO Data Services, EPPO Global Database or both in
bibtex format.
Arguments
cite
string. Possible values: 'data_services', 'global_database' or
'both'.
output
string. Name of the file to which output will be saved. If NULL
(default) results will be printed to console.